package lcsb.mapviewer.services.search;

import java.io.Serializable;

/**
 * Abstract view of objects. Contains only identificator of element. Subclasses
 * contain additional (partial) information that should be send to the client
 * side.
 * 
 * @author Piotr Gawron
 *
 */
public abstract class ElementView implements Serializable {

	/**
	 * 
	 */
	private static final long	serialVersionUID = 1L;

	/**
	 * Identifier of the {@link lcsb.mapviewer.model.map.model.Model} where Alias
	 * is located.
	 */
	private Integer						modelId;

	/**
	 * Database identifier of the object that we pass to the bean layer.
	 */
	private String						idObject;

	/**
	 * Default constructor.
	 * 
	 * @param identifier
	 *          unique identifier of the object ({@link #idObject})
	 * @param modelId
	 *          identifier of the model ({@link #modelId})
	 * 
	 */
	protected ElementView(String identifier, Integer modelId) {
		this.idObject = identifier;
		this.modelId = modelId;
	}

	/**
	 * Default constructor.
	 * 
	 * @param identifier
	 *          unique identifier of the object ({@link #idObject})
	 * @param modelId
	 *          identifier of the model ({@link #modelId})
	 * 
	 */
	protected ElementView(Integer identifier, Integer modelId) {
		this.idObject = identifier + "";
		this.modelId = modelId;
	}

	/**
	 * Constructor that should be used only for (de)serialization.
	 */
	protected ElementView() {
	}

	/**
	 * @return the modelId
	 * @see #modelId
	 */
	public Integer getModelId() {
		return modelId;
	}

	/**
	 * @param modelId
	 *          the modelId to set
	 * @see #modelId
	 */
	public void setModelId(Integer modelId) {
		this.modelId = modelId;
	}

	/**
	 * @return the idObject
	 * @see #idObject
	 */
	public String getIdObject() {
		return idObject;
	}

	/**
	 * @param idObject
	 *          the idObject to set
	 * @see #idObject
	 */
	public void setIdObject(String idObject) {
		this.idObject = idObject;
	}

	/**
	 * @param idObject
	 *          the idObject to set
	 * @see #idObject
	 */
	public void setIdObject(Integer idObject) {
		this.idObject = idObject + "";
	}

	/**
	 * @return the uniqueId
	 * @see #uniqueId
	 */
	public String getUniqueId() {
		return idObject;
	}

	/**
	 * @param uniqueId
	 *          the uniqueId to set
	 * @see #uniqueId
	 */
	public void setUniqueId(String uniqueId) {
		this.idObject = uniqueId;
	}

}
