package lcsb.mapviewer.services.search;

import java.util.ArrayList;
import java.util.Collection;
import java.util.List;

import org.springframework.transaction.annotation.Transactional;

import com.google.gson.Gson;

/**
 * Generic factory class for object to be send to the client browser.
 * 
 * @author Piotr Gawron
 *
 * @param <T>
 *          heavy data object type used on server side
 * @param <S>
 *          view class representing objects on client side
 */
@Transactional(value = "txManager")
public abstract class ElementViewFactory<T, S> {

	/**
	 * Creates view from object on server side.
	 * 
	 * @param object
	 *          original object
	 * @return view object
	 */
	public abstract S create(T object);

	/**
	 * Get json string for an object.
	 * 
	 * @param object
	 *          object to be serialized to json
	 * @return json string for an object
	 */
	public abstract String createGson(S object);

	/**
	 * Get json string for object list.
	 * 
	 * @param list
	 *          list of objects to be serialized to json
	 * @return json string input
	 */
	public String createGson(List<S> list) {
		return new Gson().toJson(list);
	}

	/**
	 * Creates list of views from objects on server side.
	 * 
	 * @param objects
	 *          original objects
	 * @return list of views
	 */
	public List<S> createList(Collection<? extends T> objects) {
		List<S> result = new ArrayList<S>();
		for (T object : objects) {
			result.add(create(object));
		}
		return result;
	}

}
