package lcsb.mapviewer.services.search.data;

import java.awt.geom.Rectangle2D;

import lcsb.mapviewer.model.map.species.Element;
import lcsb.mapviewer.services.search.ElementView;
import lcsb.mapviewer.services.search.ILightView;

/**
 * Light {@link ElementView view} for alias representing data that should be
 * send to client.
 * 
 * @author Piotr Gawron
 *
 */
public class LightAliasView extends ElementView implements ILightView {

	/**
	 * 
	 */
	private static final long	serialVersionUID = 1L;

	/**
	 * Coordinates of the alias.
	 */
	private Rectangle2D				bounds;

	/**
	 * Icon representing this alias on the map.
	 */
	private String						icon;

	/**
	 * Default constructor.
	 * 
	 * @param alias
	 *          original {@link Element} from which the object is created
	 * @param icon
	 *          {@link #icon} - icon representing this alias on the map
	 */
	protected LightAliasView(Element alias, String icon) {
		super(alias.getId(), alias.getModel().getId());
		if (alias != null) {
			this.bounds = new Rectangle2D.Double(alias.getX(), alias.getY(), alias.getWidth(), alias.getHeight());
		}
		setIcon(icon);
	}

	/**
	 * Constructory copying data from the original object.
	 * 
	 * @param original
	 *          original object from which data will be copied
	 */
	protected LightAliasView(LightAliasView original) {
		super(original.getUniqueId(), original.getModelId());
		setBounds(
				new Rectangle2D.Double(original.getBounds().getX(), original.getBounds().getY(), original.getBounds().getWidth(), original.getBounds().getHeight()));
		setIcon(original.getIcon());

	}

	/**
	 * Constructor that should be used only for (de)serialization.
	 */
	protected LightAliasView() {
		super();
	}

	/**
	 * @return the bounds
	 * @see #bounds
	 */
	public Rectangle2D getBounds() {
		return bounds;
	}

	/**
	 * @param bounds
	 *          the bounds to set
	 * @see #bounds
	 */
	public void setBounds(Rectangle2D bounds) {
		this.bounds = bounds;
	}

	/**
	 * @return the icon
	 * @see #icon
	 */
	public String getIcon() {
		return icon;
	}

	/**
	 * @param icon
	 *          the icon to set
	 * @see #icon
	 */
	public void setIcon(String icon) {
		this.icon = icon;
	}

}
