package lcsb.mapviewer.services.search.data;

import org.apache.log4j.Logger;

import com.google.gson.Gson;

import lcsb.mapviewer.model.map.species.Element;
import lcsb.mapviewer.services.search.ElementViewFactory;
import lcsb.mapviewer.services.search.ILightView;

/**
 * Factory class for {@link LightAliasView} class.
 * 
 * @author Piotr Gawron
 * 
 */
public class LightAliasViewFactory extends ElementViewFactory<Element, LightAliasView> {

	/**
	 * Default class logger.
	 */
	@SuppressWarnings("unused")
	private static Logger logger = Logger.getLogger(LightAliasViewFactory.class);

	@Override
	public LightAliasView create(Element alias) {
		return create(alias, null);
	}

	/**
	 * Creates {@link LightAliasView} for {@link Element}.
	 * 
	 * @param alias
	 *          alias for which view is created
	 * @param icon
	 *          icon that should be assigned to the view
	 * @return {@link LightAliasView} for {@link Element}
	 */
	public LightAliasView create(Element alias, String icon) {
		LightAliasView result = new LightAliasView(alias, icon);
		return result;
	}

	@Override
	public String createGson(LightAliasView object) {
		return new Gson().toJson(object);
	}

	/**
	 * Creates {@link ILightView} from {@link FullAliasView}.
	 * 
	 * @param object
	 *          original object
	 * @return new light object
	 */
	public ILightView create(FullAliasView object) {
		return new LightAliasView(object);
	}
}
