package lcsb.mapviewer.services.search.data;

import java.awt.geom.Line2D;
import java.awt.geom.Point2D;
import java.io.Serializable;

/**
 * Simple data structure that contain minimum amount of information about line.
 * Class should be used to send data to client javascript.
 * 
 * @author Piotr Gawron
 *
 */
public class LightLine implements Serializable {
	/**
	 * 
	 */
	private static final long	serialVersionUID = 1L;

	/**
	 * Starting point of the line.
	 */
	private Point2D						start;

	/**
	 * Ending point of the line.
	 */
	private Point2D						end;

	/**
	 * Direction of the line (is the line starting line, ending line or middle
	 * part of the line).
	 */
	private LightLineType			type;

	/**
	 * Default constructor.
	 * 
	 * @param line
	 *          {@link Line2D} object from which this structure is created
	 */
	public LightLine(Line2D line) {
		start = line.getP1();
		end = line.getP2();
	}

	/**
	 * Constractor that creates a copy of a {@link LightLine}.
	 * 
	 * @param line
	 *          original object
	 */
	public LightLine(LightLine line) {
		this.start = new Point2D.Double(line.getStart().getX(), line.getStart().getY());
		this.end = new Point2D.Double(line.getEnd().getX(), line.getEnd().getY());
	}

	/**
	 * @return the start
	 * @see #start
	 */
	public Point2D getStart() {
		return start;
	}

	/**
	 * @param start
	 *          the start to set
	 * @see #start
	 */
	public void setStart(Point2D start) {
		this.start = start;
	}

	/**
	 * @return the end
	 * @see #end
	 */
	public Point2D getEnd() {
		return end;
	}

	/**
	 * @param end
	 *          the end to set
	 * @see #end
	 */
	public void setEnd(Point2D end) {
		this.end = end;
	}

	/**
	 * @return the type
	 * @see #type
	 */
	public LightLineType getType() {
		return type;
	}

	/**
	 * @param type
	 *          the type to set
	 * @see #type
	 */
	public void setType(LightLineType type) {
		this.type = type;
	}
}
