package lcsb.mapviewer.services.search.db;

import java.util.ArrayList;
import java.util.List;

import org.apache.log4j.Logger;

import lcsb.mapviewer.annotation.data.Article;
import lcsb.mapviewer.services.view.AbstractTargetView;
import lcsb.mapviewer.services.view.AnnotationView;

/**
 * {@link lcsb.mapviewer.services.view.AbstractView View} for
 * {@link lcsb.mapviewer.annotation.data.Target targets}.
 * 
 * @author Piotr Gawron
 *
 */
public class TargetView extends AbstractTargetView {

	/**
	 * 
	 */
	private static final long	serialVersionUID		= 1L;

	/**
	 * Default class logger.
	 */
	@SuppressWarnings("unused")
	private static Logger			logger							= Logger.getLogger(TargetView.class);

	/**
	 * Name of the target.
	 */
	private String						name;

	/**
	 * Database from which target was acquired.
	 */
	private AnnotationView		annotation;

	/**
	 * List of genes and proteins included in the target.
	 */
	private List<GeneRow>			proteins						= new ArrayList<>();

	/**
	 * List of pubmed articles about the target.
	 */
	private List<Article>			references					= new ArrayList<>();

	/**
	 * Flag informing if target is visible in a submap or not.
	 */
	private boolean						availableInSubmodel	= false;

	/**
	 * Default constructor. Should be used only for deserialization.
	 */
	protected TargetView() {
	}

	/**
	 * Adds reference article.
	 * 
	 * @param reference
	 *          article to add
	 */
	public void addReference(Article reference) {
		references.add(reference);
	}

	/**
	 * Adds gene.
	 * 
	 * @param protein
	 *          gene to add
	 */
	public void addProtein(GeneRow protein) {
		proteins.add(protein);
	}

	/**
	 * Returns link to pubmed that enlist all references.
	 * 
	 * @return link to pubmed that enlist all references
	 */
	public String getAllReferencesLink() {
		String result = "http://www.ncbi.nlm.nih.gov/pubmed/?term=";
		for (Article article : getReferences()) {
			result += article.getId() + "+";
		}
		return result;
	}

	/**
	 * @return the name
	 * @see #name
	 */
	public String getName() {
		return name;
	}

	/**
	 * @param name
	 *          the name to set
	 * @see #name
	 */
	public void setName(String name) {
		this.name = name;
	}

	/**
	 * @return the proteins
	 * @see #proteins
	 */
	public List<GeneRow> getProteins() {
		return proteins;
	}

	/**
	 * @param proteins
	 *          the proteins to set
	 * @see #proteins
	 */
	public void setProteins(List<GeneRow> proteins) {
		this.proteins = proteins;
	}

	/**
	 * @return the references
	 * @see #references
	 */
	public List<Article> getReferences() {
		return references;
	}

	/**
	 * @param references
	 *          the references to set
	 * @see #references
	 */
	public void setReferences(List<Article> references) {
		this.references = references;
	}

	/**
	 * @return the annotation
	 * @see #annotation
	 */
	public AnnotationView getAnnotation() {
		return annotation;
	}

	/**
	 * @param annotation
	 *          the annotation to set
	 * @see #annotation
	 */
	public void setAnnotation(AnnotationView annotation) {
		this.annotation = annotation;
	}

	/**
	 * @return the availableIntSubmodel
	 * @see #availableInSubmodel
	 */
	public boolean isAvailableInSubmodel() {
		return availableInSubmodel;
	}

	/**
	 * @param availableInSubmodel
	 *          the availableIntSubmodel to set
	 * @see #availableInSubmodel
	 */
	public void setAvailableInSubmodel(boolean availableInSubmodel) {
		this.availableInSubmodel = availableInSubmodel;
	}

}
