package lcsb.mapviewer.services.view;

import java.io.Serializable;

import lcsb.mapviewer.common.ObjectUtils;

/**
 * Abstract interface of a view object for bean layer. It contains identifier of
 * the object that is represented by this view class.
 * 
 * @author Piotr Gawron
 * 
 * @param <T>
 *          type of class to be represented
 */
public abstract class AbstractView<T> implements Serializable {
	
	/**
	 * 
	 */
	private static final long	serialVersionUID	= 1L;

	/**
	 * Database identifier of the object that we pass to the bean layer.
	 */
	private Integer						idObject;

	/**
	 * Default constructor.
	 * 
	 * @param object
	 *          object that we want to pass to bean layer
	 */
	protected AbstractView(T object) {
		if (object != null) {
			idObject = ObjectUtils.getIdOfObject(object);
		}
	}

	/**
	 * Default constructor. Should be used only for deserialization.
	 */
	protected AbstractView() {
	}

	/**
	 * @return the idObject
	 * @see #idObject
	 */
	public Integer getIdObject() {
		return idObject;
	}

	/**
	 * @param idObject
	 *          the idObject to set
	 * @see #idObject
	 */
	public void setIdObject(Integer idObject) {
		this.idObject = idObject;
	}

}
