package lcsb.mapviewer.services.view;

import java.io.Serializable;

import lcsb.mapviewer.model.map.graph.DataMiningSet;
import lcsb.mapviewer.model.map.graph.DataMiningType;

/**
 * Implementation of {@link AbstractView view} for {@link DataMiningSet}
 * objects.
 * 
 * @author Piotr Gawron
 * 
 */
public class DataMiningSetView extends AbstractView<DataMiningSet> implements Serializable {

	/**
	 * 
	 */
	private static final long	serialVersionUID	= 1L;

	/**
	 * Name of the data mining set.
	 */
	private String					name;

	/**
	 * Type of the data mining set.
	 */
	private DataMiningType	type;

	/**
	 * Description of the data mining set.
	 */
	private String					description;

	/**
	 * Link to the source of the data mining set.
	 */
	private String					source;

	/**
	 * Default constructor.
	 * 
	 * @param object
	 *          original object
	 */
	protected DataMiningSetView(DataMiningSet object) {
		super(object);
		this.name = object.getName();
		this.type = object.getType();
		this.description = object.getDescription();
		this.source = object.getSource();
	}

	/**
	 * Default constructor. Should be used only for deserialization.
	 */
	protected DataMiningSetView() {
	}

	/**
	 * Default constructor.
	 * 
	 * @param original object from which data is copied
	 */
	public DataMiningSetView(DataMiningSetView original) {
		super(null);
		setIdObject(original.getIdObject());
	}

	/**
	 * @return the name
	 * @see #name
	 */
	public String getName() {
		return name;
	}

	/**
	 * @param name
	 *          the name to set
	 * @see #name
	 */
	public void setName(String name) {
		this.name = name;
	}

	/**
	 * @return the type
	 * @see #type
	 */
	public DataMiningType getType() {
		return type;
	}

	/**
	 * @param type
	 *          the type to set
	 * @see #type
	 */
	public void setType(DataMiningType type) {
		this.type = type;
	}

	/**
	 * @return the description
	 * @see #description
	 */
	public String getDescription() {
		return description;
	}

	/**
	 * @param description
	 *          the description to set
	 * @see #description
	 */
	public void setDescription(String description) {
		this.description = description;
	}

	/**
	 * @return the source
	 * @see #source
	 */
	public String getSource() {
		return source;
	}

	/**
	 * @param source
	 *          the source to set
	 * @see #source
	 */
	public void setSource(String source) {
		this.source = source;
	}

}
