package lcsb.mapviewer.services.view;

import java.io.Serializable;
import java.util.Comparator;

import lcsb.mapviewer.model.map.layout.Layout;

/**
 * This class is a client view that represents {@link Layout} class.
 * 
 * @author Piotr Gawron
 * 
 */
public class LayoutView extends AbstractView<Layout> implements Serializable {
	/**
	 * 
	 */
	private static final long	serialVersionUID	= 1L;
	
	/**
	 * Comparator for {@link LayoutView} that use database identifier as a key for
	 * comparison.
	 */
	public static final Comparator<LayoutView>	ID_COMPARATOR	= new Comparator<LayoutView>() {

																															@Override
																															public int compare(LayoutView arg0, LayoutView arg1) {
																																if (arg0 == null) {
																																	return -1;
																																} else if (arg1 == null) {
																																	return 1;
																																} else if (arg0.getIdObject() == null) {
																																	return -1;
																																} else if (arg1.getIdObject() == null) {
																																	return 1;
																																} else {
																																	return arg0.getIdObject() - arg1.getIdObject();
																																}
																															}

																														};
																														
	/**
	 * Database identifier of the model to which layout belongs to.
	 */
	private Integer															modelId;
	
	/**
	 * Name of the layout.
	 */
	private String															name;
	
	/**
	 * Short description of the layout.
	 */
	private String															description;
	
	/**
	 * Status of processing the layout.
	 * {@link lcsb.mapviewer.db.model.map.layout.LayoutStatus LayoutStatus}
	 * defines possible values.
	 */
	private String															status;
	
	/**
	 * Processing progress (value between 0..100).
	 */
	private String															progress;
	
	/**
	 * Where the files generated for this layout are stored.
	 */
	private String															directory;

	/**
	 * Who created the layout.
	 */
	private String															creator;

	/**
	 * "true" if input file from which layout was created is available, "false"
	 * otherwise.
	 */
	private String															inputDataAvailable;

	/**
	 * Default constructor.
	 */
	public LayoutView() {
		super(null);
	}

	/**
	 * Constructor that reates view from the original layout.
	 * 
	 * @param layout
	 *          original layout
	 */
	protected LayoutView(Layout layout) {
		super(layout);
	}

	/**
	 * @return the modelId
	 * @see #modelId
	 */
	public Integer getModelId() {
		return modelId;
	}

	/**
	 * @param modelId
	 *          the modelId to set
	 * @see #modelId
	 */
	public void setModelId(Integer modelId) {
		this.modelId = modelId;
	}

	/**
	 * @return the name
	 * @see #name
	 */
	public String getName() {
		return name;
	}

	/**
	 * @param name
	 *          the name to set
	 * @see #name
	 */
	public void setName(String name) {
		this.name = name;
	}

	/**
	 * @return the description
	 * @see #description
	 */
	public String getDescription() {
		return description;
	}

	/**
	 * @param description
	 *          the description to set
	 * @see #description
	 */
	public void setDescription(String description) {
		this.description = description;
	}

	/**
	 * @return the status
	 * @see #status
	 */
	public String getStatus() {
		return status;
	}

	/**
	 * @param status
	 *          the status to set
	 * @see #status
	 */
	public void setStatus(String status) {
		this.status = status;
	}

	/**
	 * @return the progress
	 * @see #progress
	 */
	public String getProgress() {
		return progress;
	}

	/**
	 * @param progress
	 *          the progress to set
	 * @see #progress
	 */
	public void setProgress(String progress) {
		this.progress = progress;
	}

	/**
	 * @return the directory
	 * @see #directory
	 */
	public String getDirectory() {
		return directory;
	}

	/**
	 * @param directory
	 *          the directory to set
	 * @see #directory
	 */
	public void setDirectory(String directory) {
		this.directory = directory;
	}

	/**
	 * @return the creator
	 * @see #creator
	 */
	public String getCreator() {
		return creator;
	}

	/**
	 * @param creator
	 *          the creator to set
	 * @see #creator
	 */
	public void setCreator(String creator) {
		this.creator = creator;
	}

	/**
	 * @return the inputDataAvailable
	 * @see #inputDataAvailable
	 */
	public String getInputDataAvailable() {
		return inputDataAvailable;
	}

	/**
	 * @param inputDataAvailable the inputDataAvailable to set
	 * @see #inputDataAvailable
	 */
	public void setInputDataAvailable(String inputDataAvailable) {
		this.inputDataAvailable = inputDataAvailable;
	}

}
