package lcsb.mapviewer.services.view;

import java.io.Serializable;
import java.util.ArrayList;
import java.util.List;

import lcsb.mapviewer.model.map.layout.ReferenceGenome;
import lcsb.mapviewer.model.map.layout.ReferenceGenomeType;

/**
 * View representation of the {@link ReferenceGenome}.
 * 
 * @author Piotr Gawron
 * 
 */
public class ReferenceGenomeView extends AbstractView<ReferenceGenome> implements Serializable {

	/**
	 * 
	 */
	private static final long										 serialVersionUID	= 1L;

	/**
	 * {@link ReferenceGenome#organism}.
	 */
	private AnnotationView											 organism;

	/**
	 * {@link ReferenceGenome#type}.
	 */
	private ReferenceGenomeType									 type;

	/**
	 * {@link ReferenceGenome#version}.
	 */
	private String															 version;

	/**
	 * Progress of download process (100 means that file is complete).
	 */
	private double															 downloadProgress;

	/**
	 * Url from which reference genome file was downloaded.
	 */
	private String															 sourceUrl;

	/**
	 * Url to local copy of reference genome file.
	 */
	private String															 localUrl;

	/**
	 * List of gene mappings for reference genome.
	 */
	private List<ReferenceGenomeGeneMappingView> geneMapping			= new ArrayList<>();

	/**
	 * Default constructor.
	 * 
	 * @param object
	 *          {@link ReferenceGenome} which this view should visualize
	 */
	protected ReferenceGenomeView(ReferenceGenome object) {
		super(object);
	}

	/**
	 * Default constructor. Should be used only for deserialization.
	 */
	protected ReferenceGenomeView() {
	}

	/**
	 * @return the organism
	 * @see #organism
	 */
	public AnnotationView getOrganism() {
		return organism;
	}

	/**
	 * @param organism
	 *          the organism to set
	 * @see #organism
	 */
	public void setOrganism(AnnotationView organism) {
		this.organism = organism;
	}

	/**
	 * @return the type
	 * @see #type
	 */
	public ReferenceGenomeType getType() {
		return type;
	}

	/**
	 * @param type
	 *          the type to set
	 * @see #type
	 */
	public void setType(ReferenceGenomeType type) {
		this.type = type;
	}

	/**
	 * @return the version
	 * @see #version
	 */
	public String getVersion() {
		return version;
	}

	/**
	 * @param version
	 *          the version to set
	 * @see #version
	 */
	public void setVersion(String version) {
		this.version = version;
	}

	/**
	 * @return the downloadProgress
	 * @see #downloadProgress
	 */
	public double getDownloadProgress() {
		return downloadProgress;
	}

	/**
	 * @param downloadProgress
	 *          the downloadProgress to set
	 * @see #downloadProgress
	 */
	public void setDownloadProgress(double downloadProgress) {
		this.downloadProgress = downloadProgress;
	}

	/**
	 * @return the sourceUrl
	 * @see #sourceUrl
	 */
	public String getSourceUrl() {
		return sourceUrl;
	}

	/**
	 * @param sourceUrl
	 *          the sourceUrl to set
	 * @see #sourceUrl
	 */
	public void setSourceUrl(String sourceUrl) {
		this.sourceUrl = sourceUrl;
	}

	/**
	 * @return the localUrl
	 * @see #localUrl
	 */
	public String getLocalUrl() {
		return localUrl;
	}

	/**
	 * @param localUrl
	 *          the localUrl to set
	 * @see #localUrl
	 */
	public void setLocalUrl(String localUrl) {
		this.localUrl = localUrl;
	}

	/**
	 * @return the geneMapping
	 * @see #geneMapping
	 */
	public List<ReferenceGenomeGeneMappingView> getGeneMapping() {
		return geneMapping;
	}

	/**
	 * @param geneMapping
	 *          the geneMapping to set
	 * @see #geneMapping
	 */
	public void setGeneMapping(List<ReferenceGenomeGeneMappingView> geneMapping) {
		this.geneMapping = geneMapping;
	}

}
