package lcsb.mapviewer.services.search.db.chemical;

import static org.junit.Assert.assertEquals;
import static org.junit.Assert.assertNotNull;
import static org.junit.Assert.assertTrue;

import java.util.ArrayList;
import java.util.List;

import org.apache.log4j.Logger;
import org.junit.After;
import org.junit.Before;
import org.junit.Test;

import lcsb.mapviewer.model.map.MiriamData;
import lcsb.mapviewer.model.map.MiriamType;
import lcsb.mapviewer.model.map.species.Element;
import lcsb.mapviewer.model.map.species.Rna;
import lcsb.mapviewer.services.ServiceTestFunctions;
import lcsb.mapviewer.services.search.db.DbSearchCriteria;

public class ChemicalServiceTest extends ServiceTestFunctions {
	Logger logger = Logger.getLogger(ChemicalServiceTest.class);

	@Before
	public void setUp() throws Exception {
	}

	@After
	public void tearDown() throws Exception {
	}

	/**
	 * @throws Exception
	 */
	@Test
	public void testgetPDChemicalByName() throws Exception {
		try {
			List<ChemicalView> result = null;
			MiriamData pdDiseaseID = new MiriamData(MiriamType.MESH_2012, "D010300");

			List<String> names = new ArrayList<String>();
			names.add("Dopamine");
			names.add("2-(2-furanyl)-7-(2-(4-(4-(2-methoxyethoxy)phenyl)-1-piperazinyl)ethyl)-7H-pyrazolo(4,3-e)(1,2,4)triazolo(1,5-c)pyrimidine-5-amine");
			names.add("Anti-Inflammatory Agents, Non-Steroidal");
			names.add("2-furanyl");
			names.add(null);
			result = chemicalService.getByNames(names, new DbSearchCriteria().disease(pdDiseaseID));
			assertNotNull(result);
			assertTrue(!result.isEmpty());
			assertTrue(result.size() == 3);
			names.clear();
			names.add("2-furanyl");
			result = chemicalService.getByNames(names, new DbSearchCriteria().disease(pdDiseaseID));
			assertNotNull(result);
			assertTrue(result.isEmpty());

			assertEquals("No warnings expected.", 0, getWarnings().size());
		} catch (Exception e) {
			e.printStackTrace();
			throw e;
		}
	}

	@Test
	public void testgetPDChemicalByName2() throws Exception {
		try {
			MiriamData pdDiseaseID = new MiriamData(MiriamType.MESH_2012, "D010300");
			String name = "Amphetamine";
			ChemicalView result = chemicalService.getByName(name, new DbSearchCriteria().disease(pdDiseaseID));
			assertNotNull(result);
			assertEquals("D000661", result.getSourceLink().getName());

			assertEquals("No warnings expected.", 0, getWarnings().size());
		} catch (Exception e) {
			e.printStackTrace();
			throw e;
		}
	}

	@Test
	public void testSearchByElements4() throws Exception {
		try {
			List<Element> elements = new ArrayList<>();
			Rna protein = new Rna("id");
			protein.setName("GDNF");
			elements.add(protein);

			List<ChemicalView> chemicals = chemicalService.getForTargets(elements, new DbSearchCriteria().disease(new MiriamData(MiriamType.MESH_2012, "D010300")));
			assertNotNull(chemicals);
			assertTrue(chemicals.size() > 0);

			assertEquals("No warnings expected.", 0, getWarnings().size());
		} catch (Exception e) {
			e.printStackTrace();
			throw e;
		}

	}

}
