package lcsb.mapviewer.services.utils.gmap;

import static org.junit.Assert.assertEquals;
import static org.junit.Assert.assertTrue;
import static org.junit.Assert.fail;

import java.awt.geom.Path2D;
import java.awt.geom.PathIterator;
import java.awt.geom.Point2D;

import lcsb.mapviewer.model.map.layout.Layout;
import lcsb.mapviewer.model.map.model.Model;
import lcsb.mapviewer.model.map.model.ModelFullIndexed;
import lcsb.mapviewer.services.ServiceTestFunctions;

import org.apache.commons.lang3.SerializationUtils;
import org.apache.log4j.Logger;
import org.junit.After;
import org.junit.Before;
import org.junit.Test;
import org.primefaces.model.map.LatLng;

public class CoordinationConverterTest extends ServiceTestFunctions {

	Logger				logger = Logger.getLogger(CoordinationConverterTest.class);
	LatLng				latLng = new LatLng(81.49230582149616, -124.1015625);
	Point2D				point	 = new Point2D.Double(12428.0859375, 6917.519531249969);
	private Model	model;

	@Before
	public void setUp() throws Exception {
		model = new ModelFullIndexed(null);
		model.setWidth(20010);
		model.setHeight(20010);
		model.setTileSize(256);
		model.setZoomLevels(7);
		model.addLayout(new Layout());
	}

	@After
	public void tearDown() throws Exception {
	}

	@Test
	public void testToLatLng() {
		try {
			CoordinationConverter converter = new CoordinationConverter(model);
			LatLng latLng2 = converter.toLatLng(point);
			assertEquals(Math.abs(latLng.getLat() - latLng2.getLat()) + Math.abs(latLng.getLng() - latLng2.getLng()), 0, EPSILON);
		} catch (Exception e) {
			e.printStackTrace();
			fail("Unknown exception occured");
		}
	}

	@Test
	public void testToPoint() {
		try {
			CoordinationConverter converter = new CoordinationConverter(model);
			Point2D point2 = converter.toPoint(latLng);
			assertEquals(0, point.distance(point2), EPSILON);
		} catch (Exception e) {
			e.printStackTrace();
			fail("Unknown exception occured");
		}
	}

	@Test
	public void testConvertPolygon() throws Exception {
		try {
			String latLngPolgyn = "84.21868256860863,164.619140625;83.3391531415795,-152.841796875;82.38497296909799,-171.1669921875;84.29345033920028,-178.1103515625;";

			CoordinationConverter converter = new CoordinationConverter(model);

			Path2D polygon = converter.latLngToPolygon(latLngPolgyn);
			PathIterator pi = polygon.getPathIterator(null);
			int counter = 0;
			while (!pi.isDone()) {
				double[] value = new double[6];
				int type = pi.currentSegment(value);
				if (type == PathIterator.SEG_MOVETO)
					counter = 1;
				else if (type == PathIterator.SEG_LINETO)
					counter++;
				pi.next();
			}
			assertEquals(4, counter);
		} catch (Exception e) {
			e.printStackTrace();
			throw e;
		}

	}

	@Test
	public void testToLatLng2() {
		try {
			Model m = new ModelFullIndexed(null);
			m.setWidth(26547.3333333333);
			m.setHeight(26547.3333333333);
			m.setZoomLevels(8);
			m.setTileSize(256);
			CoordinationConverter converter = new CoordinationConverter(m);
			Point2D p = new Point2D.Double(19920, 11040);
			LatLng latLng2 = converter.toLatLng(p);
			Point2D p2 = converter.toPoint(latLng2);
			assertTrue(p.distance(p2) < EPSILON);
		} catch (Exception e) {
			e.printStackTrace();
			throw e;
		}
	}

	@Test
	public void testSerializable() throws Exception {
		try {
			CoordinationConverter converter = new CoordinationConverter(model);
			SerializationUtils.serialize(converter);
		} catch (Exception e) {
			e.printStackTrace();
			throw e;
		}

	}

}
