package lcsb.mapviewer.services.view;

import static org.junit.Assert.assertNotNull;
import static org.junit.Assert.assertTrue;

import org.apache.log4j.Logger;
import org.junit.After;
import org.junit.Before;
import org.junit.Test;
import org.springframework.beans.factory.annotation.Autowired;

import lcsb.mapviewer.model.map.Comment;
import lcsb.mapviewer.model.map.model.Model;
import lcsb.mapviewer.model.map.model.ModelFullIndexed;
import lcsb.mapviewer.model.map.model.ModelSubmodelConnection;
import lcsb.mapviewer.model.map.model.SubmodelType;
import lcsb.mapviewer.model.map.species.GenericProtein;
import lcsb.mapviewer.model.map.species.Species;
import lcsb.mapviewer.services.ServiceTestFunctions;

public class CommentViewFactoryTest extends ServiceTestFunctions {

	Logger						 logger	= Logger.getLogger(CommentViewFactoryTest.class);

	@Autowired
	CommentViewFactory commentViewFactory;

	@Before
	public void setUp() throws Exception {
	}

	@After
	public void tearDown() throws Exception {
	}

	@Test
	public void testCreateEmpty() throws Exception {
		try {
			Object object = commentViewFactory.create(null);
			assertNotNull(object);
		} catch (Exception e) {
			e.printStackTrace();
			throw e;
		}
	}

	@Test
	public void testCreateGson() throws Exception {
		try {
			CommentView object = commentViewFactory.create(null);
			assertNotNull(commentViewFactory.createGson(object));
		} catch (Exception e) {
			e.printStackTrace();
			throw e;
		}
	}

	@Test
	public void testCreateOnSubmap() throws Exception {
		try {
			Model model = new ModelFullIndexed(null);
			Model submodel = new ModelFullIndexed(null);
			submodel.setId(1);
			Species species = new GenericProtein("id");
			species.setId(23);
			species.setName("ProteinName");
			submodel.addElement(species);
			
			model.addSubmodelConnection(new ModelSubmodelConnection(submodel, SubmodelType.UNKNOWN));
			
			Comment comment = new Comment();
			comment.setModel(model);
			comment.setSubmodel(submodel);
			comment.setTableName(species.getClass());
			comment.setTableId(species.getId());
			CommentView object = commentViewFactory.create(comment,model);
			assertTrue(object.getTitle().contains(species.getName()));
		} catch (Exception e) {
			e.printStackTrace();
			throw e;
		}
	}

}
